@@ -1,7 +1,7 @@
 /*===========================================================================*
  * This file is part of the Abstract Library for Parallel Search (ALPS).     *
  *                                                                           *
- * ALPS is distributed under the Common Public License as part of the        *
+ * ALPS is distributed under the Eclipse Public License as part of the       *
  * COIN-OR repository (http://www.coin-or.org).                              *
  *                                                                           *
  * Authors:                                                                  *
@@ -17,7 +17,7 @@
  *          Matthew Saltzman, Clemson University                             *
  *                                                                           * 
  *                                                                           *
- * Copyright (C) 2001-2007, Lehigh University, Yan Xu, and Ted Ralphs.       *
+ * Copyright (C) 2001-2011, Lehigh University, Yan Xu, and Ted Ralphs.       *
  *===========================================================================*/
 
 //#############################################################################
@@ -150,7 +150,8 @@ AbcCutGenerator::generateCuts( OsiCuts & cs , bool fullScan)
 	    generator_->generateCuts(*solver,cs);
 	} else {
 	    // Probing - return tight column bounds
-	    generator->generateCutsAndModify(*solver,cs);
+	   CglTreeInfo info;
+	    generator->generateCutsAndModify(*solver,cs,&info);
 	    const double * tightLower = generator->tightLower();
 	    const double * lower = solver->getColLower();
 	    const double * tightUpper = generator->tightUpper();
