@@ -1,7 +1,7 @@
 /*===========================================================================*
  * This file is part of the Bcps Linear Solver (BLIS).                       *
  *                                                                           *
- * BLIS is distributed under the Common Public License as part of the        *
+ * BLIS is distributed under the Eclipse Public License as part of the       *
  * COIN-OR repository (http://www.coin-or.org).                              *
  *                                                                           *
  * Authors:                                                                  *
@@ -17,9 +17,8 @@
  *          Matthew Saltzman, Clemson University                             *
  *                                                                           * 
  *                                                                           *
- * Copyright (C) 2001-2005, International Business Machines                  *
- * Corporation, Lehigh University, Yan Xu, Ted Ralphs, Matthew Salzman and   *
- * others. All Rights Reserved.                                              *
+ * Copyright (C) 2001-2011, Lehigh University, Yan Xu, and Ted Ralphs.       *
+ * All Rights Reserved.                                                      *
  *===========================================================================*/
 
 #include "CoinHelperFunctions.hpp"
@@ -301,7 +300,7 @@ BlisBranchStrategyRel::createCandBranchObjects(int numPassesLeft)
     // branch up and down to initialize pseudo-cost.
     //--------------------------------------------------
     
-    numFirsts = firstObjects.size();
+    numFirsts = static_cast<int> (firstObjects.size());
     if (numFirsts > 0) {
 	
         CoinWarmStart * ws = solver->getWarmStart();
@@ -402,7 +401,8 @@ BlisBranchStrategyRel::createCandBranchObjects(int numPassesLeft)
             score = infObjects[i]->pseudocost().getScore();
             sumDeg += score;
             
-            sortedObjects.insert(std::make_pair(score, infObjects[i])); 
+	    std::pair<const double, BlisObjectInt*> sa(score, infObjects[i]);
+	    sortedObjects.insert(sa); 
             
 #ifdef BLIS_DEBUG_MORE
             std::cout << "col[" << infObjects[i]->columnIndex() << "]="
@@ -412,7 +412,7 @@ BlisBranchStrategyRel::createCandBranchObjects(int numPassesLeft)
 
         int numNotChange = 0;
 
-        std::multimap< double, BlisObjectInt* >::iterator pos;
+        std::multimap< double, BlisObjectInt*, BlisPseuoGreater >::iterator pos;
         
         CoinWarmStart * ws = solver->getWarmStart();
         solver->getIntParam(OsiMaxNumIterationHotStart, saveLimit);
